==> paragraph_lineage-1.0.7.tar.gz: paragraph_lineage/tests/src/Unit/Plugin/Field/FieldFormatter/ParagraphIdLinkFormatterTest.php <==
<?php

namespace Drupal\Tests\paragraph_lineage\Unit\Plugin\Field\FieldFormatter;

use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Field\FieldDefinitionInterface;
use Drupal\Core\Field\FieldItemInterface;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\FieldStorageDefinitionInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\TypedData\TraversableTypedDataInterface;
use Drupal\Core\Url;
use Drupal\paragraph_lineage\Plugin\Field\FieldFormatter\ParagraphIdLinkFormatter;
use Drupal\Tests\UnitTestCase;
use Prophecy\PhpUnit\ProphecyTrait;
use Traversable;

/**
 * Simple mock implementation of FieldItemInterface that supports property
 * access.
 */
class MockFieldItem implements FieldItemInterface, \IteratorAggregate {

  /**
   * The value of the field item.
   *
   * @var mixed
   */
  public $value;

  /**
   * The entity containing this field item.
   *
   * @var \Drupal\Core\Entity\EntityInterface
   */
  protected $entity;

  /**
   * Constructs a new MockFieldItem.
   *
   * @param mixed $value
   *   The value for this field item.
   * @param \Drupal\Core\Entity\EntityInterface $entity
   *   The entity that contains this field item.
   */
  public function __construct($value, EntityInterface $entity) {
    $this->value = $value;
    $this->entity = $entity;
  }

  // Methods actually used by our formatter:

  /**
   * {@inheritdoc}
   */
  public function __get($property_name) {
    if ($property_name === 'value') {
      return $this->value;
    }
    return NULL;
  }

  /**
   * {@inheritdoc}
   */
  public function __set($property_name, $value) {
    if ($property_name === 'value') {
      $this->value = $value;
    }
  }

  /**
   * {@inheritdoc}
   */
  public function __isset($property_name) {
    return $property_name === 'value';
  }

  /**
   * {@inheritdoc}
   */
  public function __unset($property_name) {
    if ($property_name === 'value') {
      $this->value = NULL;
    }
  }

  /**
   * {@inheritdoc}
   */
  public function getEntity() {
    return $this->entity;
  }

  /**
   * {@inheritdoc}
   */
  public function getValue() {
    return ['value' => $this->value];
  }

  /**
   * {@inheritdoc}
   */
  public function setValue($value, $notify = TRUE) {
    if (isset($value['value'])) {
      $this->value = $value['value'];
    }
    elseif (!is_array($value)) {
      $this->value = $value;
    }
  }

  /**
   * {@inheritdoc}
   */
  public function isEmpty() {
    return empty($this->value);
  }

  // Methods for interface compatibility, not used in our tests:

  /**
   * {@inheritdoc}
   */
  public function getFieldDefinition() {
    return NULL;
  }

  /**
   * {@inheritdoc}
   */
  public function getParent() {
    return NULL;
  }

  /**
   * {@inheritdoc}
   */
  public function setContext($name = NULL, ?TraversableTypedDataInterface $parent = NULL) {
    // Not implemented.
  }

  /**
   * {@inheritdoc}
   */
  public function onChange($name, $notify = TRUE) {
    // Not implemented.
  }

  /**
   * {@inheritdoc}
   */
  public static function propertyDefinitions(FieldStorageDefinitionInterface $field_definition) {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public static function mainPropertyName() {
    return 'value';
  }

  /**
   * {@inheritdoc}
   */
  public static function schema(FieldStorageDefinitionInterface $field_definition) {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function getLangcode() {
    return 'en';
  }

  /**
   * {@inheritdoc}
   */
  public function view($display_options = []) {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function preSave() {
    // Not implemented.
  }

  /**
   * {@inheritdoc}
   */
  public function postSave($update) {
    // Not implemented.
  }

  /**
   * {@inheritdoc}
   */
  public function delete() {
    // Not implemented.
  }

  /**
   * {@inheritdoc}
   */
  public function deleteRevision() {
    // Not implemented.
  }

  /**
   * {@inheritdoc}
   */
  public static function generateSampleValue(FieldDefinitionInterface $field_definition) {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public static function defaultStorageSettings() {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public static function defaultFieldSettings() {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public static function storageSettingsSummary(FieldStorageDefinitionInterface $storage_definition): array {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public static function fieldSettingsSummary(FieldDefinitionInterface $field_definition): array {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public static function storageSettingsToConfigData(array $settings) {
    return $settings;
  }

  /**
   * {@inheritdoc}
   */
  public static function storageSettingsFromConfigData(array $settings) {
    return $settings;
  }

  /**
   * {@inheritdoc}
   */
  public function getIterator(): Traversable {
    return new \ArrayIterator([$this->value]);
  }

  /**
   * {@inheritdoc}
   */
  public static function fieldSettingsToConfigData(array $settings) {
    return $settings;
  }

  /**
   * {@inheritdoc}
   */
  public static function fieldSettingsFromConfigData(array $settings) {
    return $settings;
  }

  /**
   * {@inheritdoc}
   */
  public function storageSettingsForm(array &$form, FormStateInterface $form_state, $has_data) {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function fieldSettingsForm(array $form, FormStateInterface $form_state) {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public static function calculateDependencies(FieldDefinitionInterface $field_definition) {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public static function calculateStorageDependencies(FieldStorageDefinitionInterface $field_storage_definition) {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public static function onDependencyRemoval(FieldDefinitionInterface $field_definition, array $dependencies) {
    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function getDataDefinition() {
    return NULL;
  }

  /**
   * {@inheritdoc}
   */
  public function getString() {
    return (string) $this->value;
  }

  /**
   * {@inheritdoc}
   */
  public function getConstraints() {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function validate() {
    return NULL;
  }

  /**
   * {@inheritdoc}
   */
  public function applyDefaultValue($notify = TRUE) {
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function getName() {
    return '';
  }

  /**
   * {@inheritdoc}
   */
  public function getRoot() {
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function getPropertyPath() {
    return '';
  }

  /**
   * {@inheritdoc}
   */
  public static function createInstance($definition, $name = NULL, ?TraversableTypedDataInterface $parent = NULL) {
    return NULL;
  }

  /**
   * {@inheritdoc}
   */
  public function get($property_name) {
    return NULL;
  }

  /**
   * {@inheritdoc}
   */
  public function set($property_name, $value, $notify = TRUE) {
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function getProperties($include_computed = FALSE) {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function toArray() {
    return ['value' => $this->value];
  }

}

/**
 * Tests the ParagraphIdLinkFormatter.
 *
 * @group paragraph_lineage
 * @coversDefaultClass \Drupal\paragraph_lineage\Plugin\Field\FieldFormatter\ParagraphIdLinkFormatter
 */
class ParagraphIdLinkFormatterTest extends UnitTestCase {

  use ProphecyTrait;

  /**
   * The formatter under test.
   *
   * @var \Drupal\paragraph_lineage\Plugin\Field\FieldFormatter\ParagraphIdLinkFormatter
   */
  protected $formatter;

  /**
   * The string translation service.
   *
   * @var \Drupal\Core\StringTranslation\TranslationInterface|\Prophecy\Prophecy\ProphecyInterface
   */
  protected $stringTranslation;

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    $this->stringTranslation = $this->getStringTranslationStub();

    // Create a mock field definition
    $field_definition = $this->prophesize(FieldDefinitionInterface::class);
    $field_definition->getSettings()->willReturn([]);
    $field_definition->getType()->willReturn('integer');

    $this->formatter = new ParagraphIdLinkFormatter(
      'paragraph_id_link',
      [],
      $field_definition->reveal(),
      [],
      'default',
      'default',
      [],
      $this->stringTranslation
    );
  }

  /**
   * @covers ::viewElements
   */
  public function testViewElementsWithParagraphEntity() {
    // Create a mock field item list.
    $field_item_list = $this->prophesize(FieldItemListInterface::class);

    // Create a mock paragraph entity.
    $entity = $this->prophesize(EntityInterface::class);
    $entity->getEntityTypeId()->willReturn('paragraph');
    $entity->label()->willReturn('Test Paragraph');

    // Create a mock field item, using a custom test class to handle the magic property access.
    $field_item = new MockFieldItem(123, $entity->reveal());

    // Set up the field item list to return our mock field item.
    $field_item_list->willImplement(\IteratorAggregate::class);
    $field_item_list->getIterator()
      ->willReturn(new \ArrayIterator([$field_item]));

    // Run the formatter.
    $elements = $this->formatter->viewElements($field_item_list->reveal(), 'en');

    // Assert the link was created correctly.
    $this->assertEquals('link', $elements[0]['#type']);
    $this->assertStringContainsString('View lineage for Test Paragraph', (string) $elements[0]['#title']);
    $this->assertInstanceOf(Url::class, $elements[0]['#url']);
  }

  /**
   * @covers ::viewElements
   */
  public function testViewElementsWithNonParagraphEntity() {
    // Create a mock field item list.
    $field_item_list = $this->prophesize(FieldItemListInterface::class);

    // Create a mock non-paragraph entity.
    $entity = $this->prophesize(EntityInterface::class);
    $entity->getEntityTypeId()->willReturn('node');
    $entity->label()->willReturn('Test Node');

    // Create a mock field item, using a custom test class to handle the magic property access.
    $field_item = new MockFieldItem(456, $entity->reveal());

    // Set up the field item list to return our mock field item.
    $field_item_list->willImplement(\IteratorAggregate::class);
    $field_item_list->getIterator()
      ->willReturn(new \ArrayIterator([$field_item]));

    // Run the formatter.
    $elements = $this->formatter->viewElements($field_item_list->reveal(), 'en');

    // Assert the link was created correctly.
    $this->assertEquals('link', $elements[0]['#type']);
    $this->assertStringContainsString('View Test Node', (string) $elements[0]['#title']);
    $this->assertInstanceOf(Url::class, $elements[0]['#url']);
  }

  /**
   * @covers ::viewElements
   */
  public function testViewElementsWithEmptyValue() {
    // Create a mock field item list.
    $field_item_list = $this->prophesize(FieldItemListInterface::class);

    // Create a mock entity.
    $entity = $this->prophesize(EntityInterface::class);
    $entity->getEntityTypeId()->willReturn('paragraph');

    // Create a mock field item with empty value, using a custom test class to handle the magic property access.
    $field_item = new MockFieldItem(0, $entity->reveal());

    // Set up the field item list to return our mock field item.
    $field_item_list->willImplement(\IteratorAggregate::class);
    $field_item_list->getIterator()
      ->willReturn(new \ArrayIterator([$field_item]));

    // Run the formatter.
    $elements = $this->formatter->viewElements($field_item_list->reveal(), 'en');

    // Assert no elements were created.
    $this->assertEmpty($elements);
  }

}

==> paragraph_lineage-1.0.9.tar.gz: paragraph_lineage/tests/src/Unit/Plugin/Field/FieldFormatter/ParagraphIdLinkFormatterTest.php <==
<?php

namespace Drupal\Tests\paragraph_lineage\Unit\Plugin\Field\FieldFormatter;

use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Field\FieldDefinitionInterface;
use Drupal\Core\Field\FieldItemInterface;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\FieldStorageDefinitionInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\TypedData\ComplexDataDefinitionInterface;
use Drupal\Core\TypedData\TraversableTypedDataInterface;
use Drupal\Core\TypedData\TypedDataInterface;
use Drupal\Core\Url;
use Drupal\paragraph_lineage\Plugin\Field\FieldFormatter\ParagraphIdLinkFormatter;
use Drupal\Tests\UnitTestCase;
use Prophecy\PhpUnit\ProphecyTrait;
use Symfony\Component\Validator\ConstraintViolationListInterface;
use Traversable;

/**
 * Simple mock implementation of FieldItemInterface that supports property
 * access.
 */
class MockFieldItem implements FieldItemInterface, \IteratorAggregate {

  /**
   * The value of the field item.
   *
   * @var mixed
   */
  public mixed $value;

  /**
   * The entity containing this field item.
   *
   * @var \Drupal\Core\Entity\EntityInterface
   */
  protected EntityInterface $entity;

  /**
   * Constructs a new MockFieldItem.
   *
   * @param mixed $value
   *   The value for this field item.
   * @param \Drupal\Core\Entity\EntityInterface $entity
   *   The entity that contains this field item.
   */
  public function __construct($value, EntityInterface $entity) {
    $this->value = $value;
    $this->entity = $entity;
  }

  // Methods actually used by our formatter:

  /**
   * {@inheritdoc}
   */
  public function __get($property_name) {
    if ($property_name === 'value') {
      return $this->value;
    }
    return NULL;
  }

  /**
   * {@inheritdoc}
   */
  public function __set($property_name, $value) {
    if ($property_name === 'value') {
      $this->value = $value;
    }
  }

  /**
   * {@inheritdoc}
   */
  public function __isset($property_name) {
    return $property_name === 'value';
  }

  /**
   * {@inheritdoc}
   */
  public function __unset($property_name) {
    if ($property_name === 'value') {
      $this->value = NULL;
    }
  }

  /**
   * {@inheritdoc}
   */
  public function getEntity(): EntityInterface {
    return $this->entity;
  }

  /**
   * {@inheritdoc}
   */
  public function getValue() {
    return ['value' => $this->value];
  }

  /**
   * {@inheritdoc}
   */
  public function setValue($value, $notify = TRUE): void {
    if (isset($value['value'])) {
      $this->value = $value['value'];
    }
    elseif (!is_array($value)) {
      $this->value = $value;
    }
  }

  /**
   * {@inheritdoc}
   */
  public function isEmpty(): bool {
    return empty($this->value);
  }

  // Methods for interface compatibility, not used in our tests:

  /**
   * {@inheritdoc}
   */
  public function getFieldDefinition(): ?FieldDefinitionInterface {
    return NULL;
  }

  /**
   * {@inheritdoc}
   */
  public function getParent(): ?TraversableTypedDataInterface {
    return NULL;
  }

  /**
   * {@inheritdoc}
   */
  public function setContext($name = NULL, ?TraversableTypedDataInterface $parent = NULL) {
    // Not implemented.
  }

  /**
   * {@inheritdoc}
   */
  public function onChange($name, $notify = TRUE) {
    // Not implemented.
  }

  /**
   * {@inheritdoc}
   */
  public static function propertyDefinitions(FieldStorageDefinitionInterface $field_definition): array {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public static function mainPropertyName(): ?string {
    return 'value';
  }

  /**
   * {@inheritdoc}
   */
  public static function schema(FieldStorageDefinitionInterface $field_definition): array {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function getLangcode(): string {
    return 'en';
  }

  /**
   * {@inheritdoc}
   */
  public function view($display_options = []): array {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function preSave() {
    // Not implemented.
  }

  /**
   * {@inheritdoc}
   */
  public function postSave($update) {
    // Not implemented.
  }

  /**
   * {@inheritdoc}
   */
  public function delete() {
    // Not implemented.
  }

  /**
   * {@inheritdoc}
   */
  public function deleteRevision() {
    // Not implemented.
  }

  /**
   * {@inheritdoc}
   */
  public static function generateSampleValue(FieldDefinitionInterface $field_definition): array {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public static function defaultStorageSettings(): array {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public static function defaultFieldSettings(): array {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public static function storageSettingsSummary(FieldStorageDefinitionInterface $storage_definition): array {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public static function fieldSettingsSummary(FieldDefinitionInterface $field_definition): array {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public static function storageSettingsToConfigData(array $settings): array {
    return $settings;
  }

  /**
   * {@inheritdoc}
   */
  public static function storageSettingsFromConfigData(array $settings): array {
    return $settings;
  }

  /**
   * {@inheritdoc}
   */
  public function getIterator(): Traversable {
    return new \ArrayIterator([$this->value]);
  }

  /**
   * {@inheritdoc}
   */
  public static function fieldSettingsToConfigData(array $settings): array {
    return $settings;
  }

  /**
   * {@inheritdoc}
   */
  public static function fieldSettingsFromConfigData(array $settings): array {
    return $settings;
  }

  /**
   * {@inheritdoc}
   */
  public function storageSettingsForm(array &$form, FormStateInterface $form_state, $has_data): array {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function fieldSettingsForm(array $form, FormStateInterface $form_state): array {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public static function calculateDependencies(FieldDefinitionInterface $field_definition): array {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public static function calculateStorageDependencies(FieldStorageDefinitionInterface $field_storage_definition): array {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public static function onDependencyRemoval(FieldDefinitionInterface $field_definition, array $dependencies): bool {
    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function getDataDefinition(): ?ComplexDataDefinitionInterface {
    return NULL;
  }

  /**
   * {@inheritdoc}
   */
  public function getString(): string {
    return (string) $this->value;
  }

  /**
   * {@inheritdoc}
   */
  public function getConstraints(): array {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function validate(): ?ConstraintViolationListInterface {
    return NULL;
  }

  /**
   * {@inheritdoc}
   */
  public function applyDefaultValue($notify = TRUE): TypedDataInterface|MockFieldItem|static {
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function getName(): int|string|null {
    return '';
  }

  /**
   * {@inheritdoc}
   */
  public function getRoot(): TraversableTypedDataInterface|static {
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function getPropertyPath(): string {
    return '';
  }

  /**
   * {@inheritdoc}
   */
  public static function createInstance($definition, $name = NULL, ?TraversableTypedDataInterface $parent = NULL): null {
    return NULL;
  }

  /**
   * {@inheritdoc}
   */
  public function get($property_name): ?TypedDataInterface {
    return NULL;
  }

  /**
   * {@inheritdoc}
   */
  public function set($property_name, $value, $notify = TRUE): MockFieldItem {
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function getProperties($include_computed = FALSE): array {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function toArray(): array {
    return ['value' => $this->value];
  }

}

/**
 * Tests the ParagraphIdLinkFormatter.
 *
 * @group paragraph_lineage
 * @coversDefaultClass \Drupal\paragraph_lineage\Plugin\Field\FieldFormatter\ParagraphIdLinkFormatter
 */
class ParagraphIdLinkFormatterTest extends UnitTestCase {

  use ProphecyTrait;

  /**
   * The formatter under test.
   *
   * @var \Drupal\paragraph_lineage\Plugin\Field\FieldFormatter\ParagraphIdLinkFormatter
   */
  protected $formatter;

  /**
   * The string translation service.
   *
   * @var \Drupal\Core\StringTranslation\TranslationInterface|\Prophecy\Prophecy\ProphecyInterface
   */
  protected $stringTranslation;

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    $this->stringTranslation = $this->getStringTranslationStub();

    // Create a mock field definition
    $field_definition = $this->prophesize(FieldDefinitionInterface::class);
    $field_definition->getSettings()->willReturn([]);
    $field_definition->getType()->willReturn('integer');

    $this->formatter = new ParagraphIdLinkFormatter(
      'paragraph_id_link',
      [],
      $field_definition->reveal(),
      [],
      'default',
      'default',
      [],
      $this->stringTranslation
    );
  }

  /**
   * @covers ::viewElements
   */
  public function testViewElementsWithParagraphEntity() {
    // Create a mock field item list.
    $field_item_list = $this->prophesize(FieldItemListInterface::class);

    // Create a mock paragraph entity.
    $entity = $this->prophesize(EntityInterface::class);
    $entity->getEntityTypeId()->willReturn('paragraph');
    $entity->label()->willReturn('Test Paragraph');

    // Create a mock field item, using a custom test class to handle the magic property access.
    $field_item = new MockFieldItem(123, $entity->reveal());

    // Set up the field item list to return our mock field item.
    $field_item_list->willImplement(\IteratorAggregate::class);
    $field_item_list->getIterator()
      ->willReturn(new \ArrayIterator([$field_item]));

    // Run the formatter.
    $elements = $this->formatter->viewElements($field_item_list->reveal(), 'en');

    // Assert the link was created correctly.
    $this->assertEquals('link', $elements[0]['#type']);
    $this->assertStringContainsString('View lineage for Test Paragraph', (string) $elements[0]['#title']);
    $this->assertInstanceOf(Url::class, $elements[0]['#url']);
  }

  /**
   * @covers ::viewElements
   */
  public function testViewElementsWithNonParagraphEntity() {
    // Create a mock field item list.
    $field_item_list = $this->prophesize(FieldItemListInterface::class);

    // Create a mock non-paragraph entity.
    $entity = $this->prophesize(EntityInterface::class);
    $entity->getEntityTypeId()->willReturn('node');
    $entity->label()->willReturn('Test Node');

    // Create a mock field item, using a custom test class to handle the magic property access.
    $field_item = new MockFieldItem(456, $entity->reveal());

    // Set up the field item list to return our mock field item.
    $field_item_list->willImplement(\IteratorAggregate::class);
    $field_item_list->getIterator()
      ->willReturn(new \ArrayIterator([$field_item]));

    // Run the formatter.
    $elements = $this->formatter->viewElements($field_item_list->reveal(), 'en');

    // Assert the link was created correctly.
    $this->assertEquals('link', $elements[0]['#type']);
    $this->assertStringContainsString('View Test Node', (string) $elements[0]['#title']);
    $this->assertInstanceOf(Url::class, $elements[0]['#url']);
  }

  /**
   * @covers ::viewElements
   */
  public function testViewElementsWithEmptyValue() {
    // Create a mock field item list.
    $field_item_list = $this->prophesize(FieldItemListInterface::class);

    // Create a mock entity.
    $entity = $this->prophesize(EntityInterface::class);
    $entity->getEntityTypeId()->willReturn('paragraph');

    // Create a mock field item with empty value, using a custom test class to handle the magic property access.
    $field_item = new MockFieldItem(0, $entity->reveal());

    // Set up the field item list to return our mock field item.
    $field_item_list->willImplement(\IteratorAggregate::class);
    $field_item_list->getIterator()
      ->willReturn(new \ArrayIterator([$field_item]));

    // Run the formatter.
    $elements = $this->formatter->viewElements($field_item_list->reveal(), 'en');

    // Assert no elements were created.
    $this->assertEmpty($elements);
  }

}
